﻿using System.Text.Encodings.Web;
using Microsoft.AspNetCore.Html;

namespace anbs_cp.Classes;

/// <summary>
///     Конвертер типов на манер Delphi
/// </summary>
public static class TypeConverter
{
    #region Конвертация числа в строку

    /// <summary>
    ///     Преобразование int в string
    /// </summary>
    /// <param name="AInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr(int AInt) => AInt.ToString();

    /// <summary>
    ///     Преобразование uint в string
    /// </summary>
    /// <param name="AInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr(uint AInt) => AInt.ToString();

    /// <summary>
    ///     Преобразование long в string
    /// </summary>
    /// <param name="AInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr(long AInt) => AInt.ToString();

    /// <summary>
    ///     Преобразование ulong в string
    /// </summary>
    /// <param name="AInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr(ulong AInt) => AInt.ToString();

    /// <summary>
    ///     Преобразование byte в string
    /// </summary>
    /// <param name="AInt">Число</param>
    /// <returns>Строка</returns>
    public static string IntToStr(byte AInt) => AInt.ToString();

    #endregion

    #region Конвертация строки в число

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="AStr">Строка</param>
    /// <param name="ADefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static int StrToInt(string AStr, int ADefault = 0)
    {
        if (!int.TryParse(AStr, out int result)) result = ADefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="AStr">Строка</param>
    /// <param name="ADefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static uint StrToUInt(string AStr, uint ADefault = 0)
    {
        if (!uint.TryParse(AStr, out uint result)) result = ADefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="AStr">Строка</param>
    /// <param name="ADefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static long StrToInt64(string AStr, long ADefault = 0)
    {
        if (!long.TryParse(AStr, out long result)) result = ADefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="AStr">Строка</param>
    /// <param name="ADefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static ulong StrToUInt64(string AStr, ulong ADefault = 0)
    {
        if (!ulong.TryParse(AStr, out ulong result)) result = ADefault;
        return result;
    }

    /// <summary>
    ///     Преобразование строки в число
    /// </summary>
    /// <param name="AStr">Строка</param>
    /// <param name="ADefault">Значение по умолчанию (по умолчанию, 0)</param>
    /// <returns>Число</returns>
    public static byte StrToByte(string AStr, byte ADefault = 0)
    {
        if (!byte.TryParse(AStr, out byte result)) result = ADefault;
        return result;
    }

    #endregion

    #region Конвернтация IHtmlContent
    /// <summary>
    /// Преобразует тип <see cref="IHtmlContent"/> в строку <see cref="string"/>.
    /// </summary>
    /// <param name="content">Значение, которое нужно преобразовать.</param>
    /// <returns><see cref="string"/></returns>
    public static string HtmlContentToString(IHtmlContent content)
    {
        //Создаём writer
        using StringWriter writer = new();
        //Конвертируем IHtmlContent в string
        content.WriteTo(writer, HtmlEncoder.Default);
        //Возвращаем результат
        return writer.ToString();
    }

    /// <summary>
    /// Преобразует строку <see cref="string"/> в тип <see cref="IHtmlContent"/>.
    /// </summary>
    /// <param name="content">Значение, которое нужно преобразовать.</param>
    /// <returns><see cref="IHtmlContent"/></returns>
    public static IHtmlContent StringToHtmlContent(string content) => new HtmlContentBuilder().AppendHtml(content);
    #endregion
}